@@ -1,4 +1,4 @@
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 __keywords__ = ["python cgi apache stream file cache server proxy http cors"]
 
 
@@ -15,6 +15,7 @@ from .core import (
     set_status, set_header, generate_range_headers,
     execute, print, print_file, flush, main,
     log, log_construct,
-    should_return_304
+    should_return_304,
+    basic_authorization,
 )
 
