@@ -272,26 +272,26 @@ def print_file(fo, buf_size: int = 32 * 1024, range = None):
     fo.close()
 
 
-def basic_authorization(credentials: list, realm: str):
+def basic_authorization(credentials: dict):
     def basic_auth():
-        return _basic_authorization(credentials, realm)
+        return _basic_authorization(credentials)
 
     return basic_auth
 
 
-def _basic_authorization(credentials: list = None, realm: str = "Welcome! Please enter your username and password."):
+def _basic_authorization(credentials: dict = None):
     if not credentials:
-        credentials = [{"admin": "admin"}]
+        credentials = {"admin": "admin"}
     if "Authorization" not in _HEADERS:
         set_status(401)
-        set_header("WWW-Authenticate", "Basic realm={}, charset=\"UTF-8\"".format(realm))
+        set_header("WWW-Authenticate", "Basic")
         return False
     authorization = _HEADERS["Authorization"].split("Basic ")[-1]
     u, p = b64d_and_utf8d(authorization).split(":")
     if u in credentials and credentials[u] == p:
         return True
     set_status(401)
-    set_header("WWW-Authenticate", "Basic realm={}, charset=\"UTF-8\"".format(realm))
+    set_header("WWW-Authenticate", "Basic")
     return False
 
 
